@@ -1,8 +1,5 @@
 package Perinci::Access::Perl;
 
-our $DATE = '2021-08-01'; # DATE
-our $VERSION = '0.897'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -11,6 +8,11 @@ use URI::Split qw(uri_split);
 
 use parent qw(Perinci::Access::Schemeless);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-08-25'; # DATE
+our $DIST = 'Perinci-Access-Perl'; # DIST
+our $VERSION = '0.898'; # VERSION
+
 sub new {
     my $class = shift;
 
@@ -53,7 +55,7 @@ Perinci::Access::Perl - Access Perl module, functions, variables through Riap
 
 =head1 VERSION
 
-This document describes version 0.897 of Perinci::Access::Perl (from Perl distribution Perinci-Access-Perl), released on 2021-08-01.
+This document describes version 0.898 of Perinci::Access::Perl (from Perl distribution Perinci-Access-Perl), released on 2022-08-25.
 
 =head1 SYNOPSIS
 
@@ -108,12 +110,6 @@ before executed (unless you pass C<< wrap => 0 >> to the constructor).
 
 You should probably use this through L<Perinci::Access>.
 
-=head1 CONTRIBUTOR
-
-=for stopwords Steven Haryanto
-
-Steven Haryanto <sharyanto@cpan.org>
-
 =head1 FUNCTIONS
 
 =head2 new(%opts) => OBJ
@@ -153,14 +149,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-Perl>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Access-Perl>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci::Access::Schemeless>
@@ -173,11 +161,43 @@ L<Riap>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Access-Perl>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
